# RDF Helpers

Useful stuff when programming with RDFLib:
- Various ways to manipulate RDF graphs (shortcuts, really)
- Predefined graph transformations (e.g., containers --> repeated properties)
- Templated queries (substitution not limited to RDF terms like in RDFLib with `initBindings`)
- Templated graph creation (based on SPARQL `CONSTRUCT`)
- Journaled graphs
- etc.

Documentation can be found [here](https://rdf-helpers.readthedocs.io/en/latest/).

## To Do:
- More test coverage
- More predefined transformations (e.g., flat descriptions --> hierarchical descriptions)
- Code refactoring between this package and `xmptools` (move more stuff from the latter to the former)
- Documentation is still incomplete

## Contact

Author: Ora Lassila <ora@somanyaircraft.com>

Copyright (c) 2022 Ora Lassila and [So Many Aircraft](https://www.somanyaircraft.com/)
